#!/usr/bin/perl
#
#  Script for searching man pages. The result is generated as HTML.
#
#  This file is part of the SuSE help system.
#
#  Copyright (C) 2002  SuSE Linux AG, Nuernberg
#
#  Author: Cornelius Schumacher <cschum@suse.de>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#use strict;

use FindBin;
use lib $FindBin::Bin;

use susehelp;

&checkQuery;
&parseQuery;

$language = lc getQuery( "lang", "en" );
$words = getQuery( "words" );
$number = getQuery( "number", 5 );

if ( !$words ) {
  print "No search words given.\n";
  exit;
}
@words = split /\+/, $words;

# load translations
setLanguage( $language, "pac.po" );
setLanguage( $language, "susesearch.po" );

$words =~ s/([^a-zA-Z0-9 ])//g;

# Perform search
if ( !open( MAN, "apropos $words|" ) ) {
  print "Can't open apropos.\n";
  exit 1;
}
while( <MAN> ) {
#  print "RAW:$_";
  chop;
  /^([^\s]+)\s+\((.*)\)\s+-\s+(.*)$/;
  $page = $1;
  $section = $2;
  $description = $3;

  if ( $page ) { push @results, [ $page, $section, $description ]; }
}
close MAN;

&printCgiHeader;

# Print HTML header
print "<html><head><title>Package Descriptions - Search Result</title></head>";
print "<body>\n";

# Print search result header
$nummatches = @results;

printSearchResultHeader( $nummatches, $number );

if ( $nummatches > 0 ) {
  print "<ul>\n";

  $count = 0;
  for $result ( @results ) {
    ( $page, $section, $description ) = @$result;
    my $url = createCgiUrl( "manshow.cgi" ) . "&page=$page&section=$section";
    print "<li><a href=\"$url\">";
    print "$page - $description</a></li>\n";
    if ( ++$count == $number ) { last; }
  }

  print "</ul>\n";
}

# Print footer
print "</body></html>\n";

1;
