#!/usr/bin/perl
#
#  Script for displaying the state of search indices.
#
#  This file is part of the SuSE help system.
#
#  Copyright (C) 2002  SuSE Linux AG, Nuernberg
#
#  Author: Cornelius Schumacher <cschum@suse.de>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

use FindBin;
use lib $FindBin::Bin;

#use strict;
use utf8;

use susehelp;

&parseQuery;

$lang = lc getQuery( "lang", "en" );
$metapath = getQuery( "path" );
$depth = getQuery( "depth", 9999 );
$cgiprefix = getQuery( "cgiprefix", "cgi:" );

&registerCgiPrefix( $cgiprefix );

# for the web server
&printCgiHeader;

my $out = "--HEADER_FULL:--";

$out .= "<table border=1 cellpadding=3><tr> <th>Name</th> <th>Identifier</th>";
$out .= "<th>Index exists</th>";
$out .= "<th>Default Enabled</th> <th>Enabled</th>";
$out .= "<th>SearchMethod</th> ";
$out .= "<th>Search</th>";
$out .= "<th>Indexer</th> <th>Test File</th> </tr>\n";

&traverseMetaDir( $metapath, $depth, $lang, "::showfileentry", "::showdirentry",
                  "::dirdown", "::dirup" );

$out .="</table>\n";

$out .= "--FOOTER_FULL:--";

&printPage( $out );

exit 0;

sub yesNoLabel($)
{
  my $v = shift;

  $result = "<td><font color=";

  if ( $v ) { $result .= "green>Yes"; }
  else { $result .= "red>No"; }

  $result .= "</font></td>";
  
  return $result;
}

sub showfileentry($)
{
  my $docentry = shift;
  
  my ( $name, $comment, $docpath, $search, $searchmethod, $identifier,
       $testfile, $indexer );

  $docpath = $docentry->docpath;
  $name = $docentry->name;
  $comment = $docentry->comment;
  $search = $docentry->search;
  $searchmethod = $docentry->searchmethod;
  $identifier = $docentry->identifier;
  $testfile = $docentry->indextestfile;
  $indexer = $docentry->indexer;
  
  if ( !$searchmethod && !$search ) { return; }

  $out .= "  <tr>";
  $out .= "<td>$name</td> <td>$identifier</td> ";
  if ( $testfile ) {
    $out .= &yesNoLabel( -e $testfile );
  } else {
    $out .= "<td>---</td>";
  }
  $out .= &yesNoLabel( $docentry->searchenableddefault );

  if ( %searchEnabled ) {
    $out .= &yesNoLabel( $searchEnabled{ $identifier } );
  } else {
    $out .= "<td>---</td>";
  }
  
  $out .= "<td>$searchmethod</td> ";
  $out .= "<td>$search</td>";
  
  $out .= "<td>$indexer</td> <td>$testfile</td> ";
  $out .= "</tr>\n";

  return;

  if ( $testfile && !-e $testfile ) { return; }

  $out .= "  <li><input type=\"checkbox\" name=\"scope\" value=\"$identifier\"";
  my $checked;
  if ( %searchEnabled ) {
    if ( $searchEnabled{ $identifier } ) { $checked = 1; }
  } else {
    if ( $docentry->searchenableddefault ) { $checked = 1; }
  }
  if ( $checked ) { $out .= " checked=\"checked\""; }
  $out .= ">$name</input></li>\n";
}

sub showdirentry($$)
{
}

sub dirdown()
{
#  $out .= "<ul>\n";
}

sub dirup()
{
#  $out .= "</ul>\n";
}

