#!/usr/bin/perl
#
#  Search script.
#
#  This file is part of the SuSE help system.
#
#  Copyright (C) 2002  SuSE Linux AG, Nuernberg
#
#  Author: Cornelius Schumacher <cschum@suse.de>
#
#  This program is free software; you can redistribute it and/or modify
#  it under the terms of the GNU General Public License as published by
#  the Free Software Foundation; either version 2 of the License, or
#  (at your option) any later version.
#
#  This program is distributed in the hope that it will be useful,
#  but WITHOUT ANY WARRANTY; without even the implied warranty of
#  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
#  GNU General Public License for more details.
#
#  You should have received a copy of the GNU General Public License
#  along with this program; if not, write to the Free Software
#  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

use FindBin;
use lib $FindBin::Bin;

use Encode;

#use strict;
use utf8;
use open IO => ':utf8';
use open ':std';

use susehelp;

#&dbg("QUERY_STRING: $ENV{ QUERY_STRING }");

&checkQuery;
&parseQuery;

$lang = lc getQuery( "lang", "en" );
$metapath = getQuery( "path" );
$depth = getQuery( "depth", 1000 );
$cgiprefix = getQuery( "cgiprefix", "cgi:" );
$header = getQuery( "header", 1 );

$words = getQuery( "words" );
$nummatches = getQuery( "num", 5 );
$method = getQuery( "method", "and" );

#&dbg("WORDS: $words");

if ( length( $lang ) != 2 || $lang =~ /[^\w]/ ) { $lang = "en" }
if ( $method ne "or" && $method ne "and" ) { $method = "and"; }
if ( $nummatches =~ /\D/ ) { $nummatches = 5; }
$words =~ s/[^\p{IsWord} \+,]//g;

&setLanguage( $lang );

&registerCgiPrefix( $cgiprefix );

# for the web server
&printCgiHeader;

my $out;

if ( $header ) {
  $out = "--HEADER_FULL:--";
} else {
  $out = "--HEADER:--";
}

if ( $lang eq "de" ) {
  $out .= "<h1>Suchergebnisse f\xFCr '$words'</h1>";
} else {
  $out .= "<h1>Search Results for '$words'</h1>";
}

#$out .= "WORDS: $words<br>NUMMATCHES: $nummatches<br>LANG: $lang<br>";
#$out .= "METHOD: $method\n";

if ( !$words ) {
  $out .= "<p>Please provide a search term.</p>\n";
} else {
#  $out .= "<ul>\n";

  my $query = $ENV{ QUERY_STRING };
  my @query = split /&/, $query;

  my $term;    
  foreach $term ( @query ) {
    $term =~ /^(\w*)=([\w\.-]*)$/;
    my $key = $1;
    my $value = $2;
    if ( $key eq "scope" ) {
      $searchEnabled{ $value } = 1;
    }
  }

  &traverseMetaDir( $metapath, $depth, $lang, "::showfileentry", "::showdirentry",
                    "::dirdown", "::dirup" );

#  $out .= "</ul>\n";
}

if ( $header ) {
  $out .= "--FOOTER_FULL:--";
} else {
  $out .= "--FOOTER:--";
}

&printPage( $out );

exit 0;


sub showfileentry($)
{
  my $docentry = shift;
  
  my ( $name, $comment, $docpath, $search, $searchmethod, $identifier );

  $docpath = $docentry->docpath;
  $name = $docentry->name;
  $comment = $docentry->comment;
  $search = $docentry->search;
  $searchmethod = $docentry->searchmethod;
  $identifier = $docentry->identifier;

#  &dbg( "SEARCH: $identifier: $name" );

  if ( %searchEnabled ) {
    if ( !$searchEnabled{ $identifier } ) { return; }
  } else {
    if ( !$docentry->searchenableddefault ) { return; }
  }

#  $out .= "is enabled<br>\n";

#  $out .= "++SEARCH: '$search' ++SEARCHMETHOD: '$searchmethod'<br>\n";

  &dbg( "DOCENTRY: $name, SEARCH: $search, SEARCHMETHOD: $searchmethod" );

  if ( $search && $search !~ /^cgi:/ ) {
    return;
  }

  $search =~ s/^cgi://;

  if ( !$search ) {
    return;
  }

  $out .= "<h2><font color=\"red\">" . decode( "utf-8", $name ) . "</h2>\n";

  $search =~ s/%k/$words/;
  $search =~ s/%n/$nummatches/;
  $search =~ s/%m/$method/;
  $search =~ s/%l/$lang/;
  $search =~ s/%i/$identifier/;
  $search =~ s/%c/$cgiprefix/;

#  $out .= "SEARCHQUERY: $search<br>";

  $search =~ /^(.*)\?(.*)/;
  my $cgibin = $1;
  my $cgiquery = $2;
#  $out .= "CGIBIN: $cgibin<br>";

  $cgiquery = createCgiQuery( $cgiquery, $lang );

  &dbg( "CGIQUERY: $cgibin $cgiquery" );
    
  $ENV{ "SERVER_PROTOCOL" } = "HTTP";
  $ENV{ "REQUEST_METHOD" } = "GET";
  $ENV{ "QUERY_STRING"} = $cgiquery;

  &dbg( "CALL '$susehelp::susehelpcgidir/$cgibin'" );
  if ( !open( CGI, "$susehelp::susehelpcgidir/$cgibin|" ) ) {
    $out .= "Error opening search program '$susehelp::susehelpcgidir/$cgibin'.\n";
  } else {
    my $body = 0;
    while( <CGI> ) {
#      print STDERR "  CGI: $_";
      if ( !$body ) {
        if ( /<(body|BODY).*>(.*)/ ) {
          $out .= $2;
#          print STDERR " BODYSTART: $1\n";
          $body = 1;
        }
      } else {
        if ( /(.*)<\/body/ ) {
#          print STDERR " BODYEND: $1\n";
          $out .= $1;
          last;
        }
        $out .= $_;
      }
    }
    close CGI;
    if ( $? != 0 ) {
      $out .= "Search program returned error $?\n";
    }
  }

#  print STDERR "CALL done.\n";
}

sub showdirentry($$)
{
  my $docentry = shift;

  my $id = $docentry->identifier;

#  &dbg( "showdir $id" );
  
  showfileentry( $docentry );
}

sub dirdown()
{
}

sub dirup()
{
}
